package net.pingex.dcf.commands;

import net.pingex.dcf.permissions.DefaultPermission;
import java.lang.annotation.ElementType;
import java.lang.annotation.Retention;
import java.lang.annotation.RetentionPolicy;
import java.lang.annotation.Target;

/**
 * Indicated a method which is in fact a command
 */
@Retention(RetentionPolicy.RUNTIME)
@Target(ElementType.METHOD)
public @interface AnnotatedCommand
{
	/**
	 * Main name of the command
	 */
	String name();

	/**
	 * Command can also be called using the following list of aliases
	 */
	String[] aliases() default {};

	/**
	 * Description of the command.
	 */
	String description() default Command.Defaults.DESCRIPTION;

	/**
	 * Is the command enabled ? Can it be invoked ?
	 */
	boolean isEnabled() default Command.Defaults.IS_ENABLED;

	/**
	 * Command usage help
	 */
	String usage() default Command.Defaults.USAGE;

	/**
	 * Default permission, ie. when the permissions provider doesn't return anything.
	 */
	@Deprecated
	DefaultPermission defaultPermission() default DefaultPermission.EVERYONE;
}
