package net.pingex.dcf.permissions.audit;

import net.pingex.dcf.commands.Context;
import net.pingex.dcf.commands.audit.AuditResult;
import net.pingex.dcf.commands.audit.IAuditComponentProvider;
import net.pingex.dcf.permissions.ICommandPermissionsProvider;

/**
 * This class checks permission against a rule defined for a specific user in a specific guild.
 */
public class UserGuildCheck implements IAuditComponentProvider
{
	/**
	 * Permissions provider to use
	 */
	private ICommandPermissionsProvider provider;

	/**
	 * Provider for this object to use
	 * @param provider Permissions provider this object will use
	 */
	public UserGuildCheck(ICommandPermissionsProvider provider)
	{
		this.provider = provider;
	}

	@Override
	public AuditResult doAudit(Context context)
	{
		// Check for guild
		if(context.getChannel().getGuild() == null)
			return new AuditResult(AuditResult.ResultCode.NOOP, "This channel is not part of a guild.");

		Boolean returnedValue = provider.validateUser(context.getChannel().getGuild(), context.getUser(), context.getCommand());

		if(returnedValue == null) // No rule for user in this guild
			return new AuditResult(AuditResult.ResultCode.NOOP, "No guild rule for this user.");
		else if(returnedValue) // Rule says yes
			return new AuditResult(AuditResult.ResultCode.PASS);
		else // Rule says no
			return new AuditResult(AuditResult.ResultCode.FAIL, "Guild rule denied access for this user.");
	}

	@Override
	public String name()
	{
		return "User vs guild check";
	}

	@Override
	public String description()
	{
		return "Checks against a guild rule defined for an user.";
	}

	@Override
	public int priority()
	{
		return 1;
	}
}
